xquery version "3.1";

(:~
 : description
 :
 : @author unknown
 : @author Stefan Hynek
 : @version 0.1
:)

(: updated in generic SADE :)

module namespace nav="https://sade.textgrid.de/ns/navigation";

import module namespace app="https://sade.textgrid.de/ns/app" at "app.xqm";
import module namespace config="https://sade.textgrid.de/ns/config" at "config.xqm";
import module namespace templates="http://exist-db.org/xquery/templates";
import module namespace bdn-utils="http://bdn-edition.de/ns/utils" at "bdn/utils.xqm";

declare variable $nav:module-key := "navigation";
declare variable $nav:lang := app:getLanguage();
declare variable $nav:langDefault := (config:get("lang.default", "multilanguage"));
declare variable $nav:langTest :=   if ($nav:langDefault = "")
                                    then true()
                                    else ($nav:lang = $nav:langDefault);

declare
    %templates:wrap
function nav:navitems($node as node(), $model as map(*)) as map(*) {
    let $confLocation := config:get("location", $nav:module-key)
    let $navitems := doc( $config:app-root || $confLocation)//navigation/*
    return
        map { "navitems" : $navitems }
};

declare function nav:head($node as node(), $model as map(*)) {
    switch(local-name($model("item")))
        case "submenu" return
            element { node-name($node) } {
                    $node/@*,
                    if ($nav:langTest)
                    then (string($model("item")/@label))
                    else string($model("item")/@*[local-name( . ) = "label-" || $nav:lang]),
                    $node/node()
            }
        case "item" return
            element { node-name($node) } {
                    attribute href {$model("item")/@link},
                    if ($nav:langTest or not($model("subitem")/@*[local-name() ="label-" || $nav:lang]))
                    then string($model("item")/@label)
                    else string($model("item")/@*[local-name( . ) = "label-" || $nav:lang])
            }
        default return
            <b>not defined: { node-name($model("item")) }</b>
};

declare
    %templates:wrap
function nav:subitems($node as node(), $model as map(*)) as map(*)
{
    map{ "subitems" : $model("item")/*}
};

declare function nav:subitem($node as node(), $model as map(*))
{
  if ($model("subitem")/@class) then
        <span class="{$model("subitem")/@class}">&#160;</span>

    else if ($model("subitem")/@type = "work-subitem") then
        ()
    (: element(item)/@type = "work" are the elements that refer to a edition
     : author, e.g. "Nösselt" or "Griesbach"
     : only fill in published authors
     :
     : TBD: merge into generic SADE
     : TBD: refactor to using switch and a template file
     :)
    else if ($model("subitem")/@type = "work") then
      (
        element ul
        {
          if (bdn-utils:check-published($model("subitem")/@id))
          then
          (
          attribute class {"navbar-work navbar-work-btn"},
          element li
          {
            attribute class {"navbar-work-label"},
            element span
            {
              attribute class {"bdn-series-no"},
              string($model("subitem")/@n || ":")
            },
            element span
            {
              attribute class {"bdn-series-short-title"},
              string($model("subitem")/@label || " "),
              <i class="fas fa-caret-down" />
            }
          }
        ) else ()
        },
        element div
        {
            attribute class {"navbar-work-subitem-container"},
            let $corresp-work-subitems :=
                if ($model("subitem")/following::*[@type = "work"]) then
                    $model("subitem")/following-sibling::*[. << $model("subitem")/following::*[@type = "work"][1]]
                else
                    $model("subitem")/following-sibling::*
            return
                element ul {
                    attribute class {"navbar-work-list"},
                    for $item in $corresp-work-subitems return
                        <li>{nav:make-subitem-links($item)}</li>
                }
        }
      )

    else if ($model("subitem")/@type = "normal-subitem") then
        element div {
            attribute class {"navbar-normal-subitem"},
            element div {
                attribute class {"navbar-normal-subitem-label"},
                nav:make-subitem-links($model("subitem"))
            }
        }

    else if ($model("subitem")/name() != 'divider') then
        nav:make-subitem-links($model("subitem"))

    else
        <span>&#160;</span>
};

declare function nav:make-subitem-links($subitem as element())
{
    element a {
        if ($subitem/ancestor::*/@label = "Edition") then
            attribute class {"navbar-work-subitem"}
        else
            (),
        if (string($subitem/@link)) then
            attribute href { string($subitem/@link)}
        else
            (),
        if (string($subitem/@target)) then
            attribute target {string($subitem/@target)}
        else
            (),
        if ($nav:langTest
        or not($subitem/@*[local-name() ="label-" || $nav:lang])) then
            string($subitem/@label)
        else
            string($subitem/@*[local-name( . ) = "label-" || $nav:lang])
    }
};
